summaryrefslogtreecommitdiff
path: root/src/plugins/scripts/python/weechat-python.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugins/scripts/python/weechat-python.c')
-rw-r--r--src/plugins/scripts/python/weechat-python.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/plugins/scripts/python/weechat-python.c b/src/plugins/scripts/python/weechat-python.c
index 51236028f..b117cb9e2 100644
--- a/src/plugins/scripts/python/weechat-python.c
+++ b/src/plugins/scripts/python/weechat-python.c
@@ -581,12 +581,12 @@ weechat_python_completion_cb (void *data, char *completion,
}
/*
* weechat_python_dump_data_cb: dump Python plugin data in WeeChat log file
*/
int
-weechat_python_dump_data_cb (void *data, char *signal, char *type_data,
- void *signal_data)
+weechat_python_debug_dump_cb (void *data, char *signal, char *type_data,
+ void *signal_data)
{
/* make C compiler happy */
(void) data;
@@ -638,7 +638,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin)
script_init (weechat_python_plugin,
&weechat_python_command_cb,
&weechat_python_completion_cb,
- &weechat_python_dump_data_cb,
+ &weechat_python_debug_dump_cb,
&weechat_python_load_cb);
/* init ok */
@@ -581,12 +581,12 @@ weechat_python_completion_cb (void *data, char *completion,
}
/*
- * weechat_python_dump_data_cb: dump Python plugin data in WeeChat log file
+ * weechat_python_debug_dump_cb: dump Python plugin data in WeeChat log file
*/
int